--/*
--** ----------------------------------------------------------------
--** idp.c  -  Modulo que calcula Integral de Divisao de Polinomios.
--**
--** ----------------------------------------------------------------
--*/
module(..., package.seeall);
print("idp module loaded")

--/*@{*/
--/**
--** @name Modulo que calcula integral de divisao de polinomios
--**
--** @date    25-Out-2005
--** @author  Alexandre Lopes e Luiz F. Martha
--** @version 1.0
--**
--** Este modulo contem uma funcao que calcula a integral
--** unidimensional de divisao de polinomios em uma faixa
--** arbitraria.
--**
--** Revisoes:
--**
--*/
--
--/*
--** ---------------------------------------------------------------
--** Definicoes e variaveis globais:
--*/
--
--/*
--** ---------------------------------------------------------------
--** Definicoes e variaveis locais:
--*/
--
--/*
--** ---------------------------------------------------------------
--** Funcoes locais:
--*/
--/*====================  integraDivPoliLocal  ===================*/
--
--/** Funcao que realiza a integracao da divisao de dois polinomios
-- ** no intervalo [a,b].
-- ** A funcao utiliza integracao numerica de Gauss com quatro
-- ** pontos de integracao.
-- **
-- **  @param coefPoliNumerador   - coeficientes do polinomio do numerador
-- **                               ( primeiro posio  o grau )
-- **  @param coefPoliDenominador - coeficientes do polinomio do denominador
-- **                               ( primeiro posio  o grau )
-- **  @param a           - limite inferior de integracao
-- **  @param b           - limite superior de integracao
-- **
-- ** @return
-- **  resultado da integracao
-- **/
function integraDivPoliLocal( coefPoliNumerador, coefPoliDenominador, a, b )

  -- /** abscissas de Gauss considerando xi variando de 0 a 1 */
  gaussAbscissas = { 0.069431844202974,
                            0.330009478207572,
                            0.669990521792428,
                            0.930568155797026};

  -- /** pesos de Gauss considerando xi variando de 0 a 1 */
  gaussPesos = { 0.173927422568727,
                        0.326072577431273,
                        0.326072577431273,
                        0.173927422568727};

  -- /** numero de pontos de Gauss */
  local numPontosGauss = 4;

  -- /** grau do numerador */
  local grauNumerador   = coefPoliNumerador[1];

  -- /** grau do denominador */
  local grauDenominador = coefPoliDenominador[1];

  -- /** variavel auxiliar para armazenar o valor do numerador */
  local poliNumerador = 0.0

  -- /** variavel auxiliar para armazenar o valor do denominador */
  local poliDenominador = 0.0

  -- /** variavel auxiliar para armazenar o valor da integral */
  local integral = 0.0

  local i = 1
  local j = 1

  for i = 1,numPontosGauss do

    poliNumerador = 0.0
    poliDenominador = 0.0
    
    for j = 1,grauNumerador+1 do
      poliNumerador = (coefPoliNumerador[j+1] * 
                      math.pow( a*(1-gaussAbscissas[i]) + b*gaussAbscissas[i], grauNumerador-j ))
                      + poliNumerador
    end


    for j = 1, grauDenominador+1 do
      poliDenominador = (coefPoliDenominador[j+1] *
                        math.pow( a*(1-gaussAbscissas[i]) + b*gaussAbscissas[i], grauDenominador-j ))
                        + poliDenominador
    end
    integral = (b-a) * (poliNumerador/poliDenominador) * gaussPesos[i] + integral
  end
  return integral

end



--** ---------------------------------------------------------------
--** Funcoes exportadas:
--*/
--
--/*=====================  idpIntegraDivPoli  ====================*/
--
function idpIntegraDivPoli( coefPoliNumerador, coefPoliDenominador, a, b )

  local integral = 0
  local integralParcial1 = 0
  local integralParcial2 = 0
  local erro = 1e-8;

  integral = integraDivPoliLocal( coefPoliNumerador,
                                  coefPoliDenominador, a , b );
  integralParcial1 = integraDivPoliLocal( coefPoliNumerador,
                                          coefPoliDenominador, a, (a+b)*0.5 );
  integralParcial2 = integraDivPoliLocal( coefPoliNumerador,
                                          coefPoliDenominador,(a+b)*0.5, b );

  if (math.abs( integral - (integralParcial1 + integralParcial2) ) < erro ) then
    return( integral );
  else
    return(
      idpIntegraDivPoli( coefPoliNumerador,coefPoliDenominador,a, (a+b)*0.5 ) +
      idpIntegraDivPoli( coefPoliNumerador,coefPoliDenominador, (a+b)*0.5, b )
    );
  end
end

--***************************** End of Module********************************--